# Installation

In a new virtual environment, install simply the package via
[pipy](https://pypi.org/project/cliconfig/):

```bash
pip install cliconfig
```

This package is supported on Linux, macOS and Windows.
